/* ***** BEGIN LICENSE BLOCK *****
Version: MPL 1.1/LGPL 2.1/GPL 2.0

The contents of this file are subject to the Mozilla Public License Version 
1.1 (the "License"); you may not use this file except in compliance with
...
for the specific language governing rights and limitations under the
License.

The Original Code is for Luminous Forts.

The Initial Developer of the Original Code is Hekar Khani.
Portions created by the Hekar Khani are Copyright (C) 2010
Hekar Khani. All Rights Reserved.

Contributor(s):
Hekar Khani <hekark@gmail.com>

Alternatively, the contents of this file may be used under the terms of
either of the GNU General Public License Version 2 or later (the "GPL"),
...
the terms of any one of the MPL, the GPL or the LGPL.

***** END LICENSE BLOCK ***** */

#include "cbase.h"
#ifdef MOD_LUA
#include "Lua_Main.h"

CBasePlayer *Lua_PlayerByName( const std::string& name )
{
	return UTIL_PlayerByName( name.c_str() );
}

BEGIN_LUA
	luabind::module( LuaManager()->GetState() ) 
	[
		luabind::def("util_set_size", UTIL_SetSize),
		luabind::def("util_clear_trace", UTIL_ClearTrace),
		luabind::def("util_set_trace", UTIL_SetTrace),
		luabind::def("util_player_by_index", UTIL_PlayerByIndex),
		luabind::def("util_get_local_player", UTIL_GetLocalPlayer),
		luabind::def("util_get_listen_server_host", UTIL_GetListenServerHost),
		luabind::def("util_player_by_user_id", UTIL_PlayerByUserId),
		luabind::def("util_player_by_name", UTIL_PlayerByName),
		luabind::def("util_is_command_issued_by_server_admin", UTIL_IsCommandIssuedByServerAdmin),
		luabind::def("util_entity_by_index", UTIL_EntityByIndex),
		luabind::def("util_get_player_connection_info", UTIL_GetPlayerConnectionInfo),
		luabind::def("util_set_client_visibility_pvs", UTIL_SetClientVisibilityPVS),
		luabind::def("util_client_pvsis_expanded", UTIL_ClientPVSIsExpanded),
		luabind::def("util_find_client_in_visibility_pvs", UTIL_FindClientInVisibilityPVS),
		luabind::def("util_entities_in_pvs", UTIL_EntitiesInPVS),
		luabind::def("util_remove", (void(*)(CBaseEntity *))UTIL_Remove),
		luabind::def("util_disable_remove_immediate", UTIL_DisableRemoveImmediate),
		luabind::def("util_enable_remove_immediate", UTIL_EnableRemoveImmediate),
		luabind::def("util_remove_immediate", UTIL_RemoveImmediate),
		luabind::def("util_drop_to_floor", UTIL_DropToFloor),
		luabind::def("util_check_bottom", UTIL_CheckBottom),
		luabind::def("util_set_origin", UTIL_SetOrigin),
		luabind::def("util_emit_ambient_sound", UTIL_EmitAmbientSound),
		luabind::def("util_particle_effect", UTIL_ParticleEffect),
		luabind::def("util_screen_shake", UTIL_ScreenShake),
		luabind::def("util_screen_shake_object", UTIL_ScreenShakeObject),
		luabind::def("util_view_punch", UTIL_ViewPunch),
		luabind::def("util_show_message", UTIL_ShowMessage),
		luabind::def("util_show_message_all", UTIL_ShowMessageAll),
		luabind::def("util_screen_fade_all", UTIL_ScreenFadeAll),
		luabind::def("util_screen_fade", UTIL_ScreenFade),
		luabind::def("util_muzzle_flash", UTIL_MuzzleFlash),
		luabind::def("util_point_on_line_nearest_point", UTIL_PointOnLineNearestPoint),
		luabind::def("util_entity_in_solid", UTIL_EntityInSolid),
		luabind::def("util_is_master_triggered", UTIL_IsMasterTriggered),
		luabind::def("util_blood_stream", UTIL_BloodStream),
		luabind::def("util_blood_spray", UTIL_BloodSpray),
		luabind::def("util_random_blood_vector", UTIL_RandomBloodVector),
		//luabind::def("util_impact_trace", UTIL_ImpactTrace),
		luabind::def("util_player_decal_trace", UTIL_PlayerDecalTrace),
		luabind::def("util_smoke", UTIL_Smoke),
		luabind::def("util_axis_string_to_point_dir", UTIL_AxisStringToPointDir),
		luabind::def("util_axis_string_to_point_point", UTIL_AxisStringToPointPoint),
		luabind::def("util_axis_string_to_unit_dir", UTIL_AxisStringToUnitDir),
		luabind::def("util_clip_punch_angle_offset", UTIL_ClipPunchAngleOffset),
		luabind::def("util_predicted_position", UTIL_PredictedPosition),
		//luabind::def("util_beam", UTIL_Beam),
		luabind::def("util_is_valid_entity", UTIL_IsValidEntity),
		luabind::def("util_teams_match", UTIL_TeamsMatch),
		luabind::def("util_snap_direction_to_axis", UTIL_SnapDirectionToAxis),
		luabind::def("util_point_at_entity", UTIL_PointAtEntity),
		luabind::def("util_point_at_named_entity", UTIL_PointAtNamedEntity),
		luabind::def("util_transfer_pose_parameters", UTIL_TransferPoseParameters),
		luabind::def("util_water_level", UTIL_WaterLevel),
		luabind::def("util_find_water_surface", UTIL_FindWaterSurface),
		luabind::def("util_bubbles", UTIL_Bubbles),
		luabind::def("util_bubble_trail", UTIL_BubbleTrail),
		luabind::def("util_precache_other", UTIL_PrecacheOther),
		luabind::def("util_client_print_all", (void(*)(const char*))UTIL_ClientPrintAll),
		luabind::def("util_center_print_all", (void(*)(const char*))UTIL_CenterPrintAll),
		luabind::def("util_validate_sound_name", UTIL_ValidateSoundName),
		luabind::def("util_client_print_filter", UTIL_ClientPrintFilter),
		luabind::def("util_say_text", UTIL_SayText),
		luabind::def("util_say_text_all", (void(*)(const char*))UTIL_SayTextAll),
		luabind::def("util_say_text_filter", UTIL_SayTextFilter),
		luabind::def("util_say_text2_filter", UTIL_SayText2Filter),
		luabind::def("util_load_file_for_me", UTIL_LoadFileForMe),
		luabind::def("util_free_file", UTIL_FreeFile),
		luabind::def("util_set_model", UTIL_SetModel),
		luabind::def("util_hud_message_all", UTIL_HudMessageAll),
		luabind::def("util_hud_message", UTIL_HudMessage),
		luabind::def("util_hud_hint_text", UTIL_HudHintText),
		luabind::def("util_scale_for_gravity", UTIL_ScaleForGravity),
		luabind::def("util_dist_approx", UTIL_DistApprox),
		luabind::def("util_dist_approx2_d", UTIL_DistApprox2D),
		luabind::def("util_get_command_client_index", UTIL_GetCommandClientIndex),
		luabind::def("util_get_command_client", UTIL_GetCommandClient),
		//luabind::def("util_get_mod_dir", UTIL_GetModDir),
		luabind::def("util_world_to_parent_space", (void(*)(CBaseEntity *, Vector &, QAngle &))UTIL_WorldToParentSpace),
		luabind::def("util_parent_to_world_space", (void(*)(CBaseEntity *, Vector &, QAngle &))UTIL_ParentToWorldSpace),
		luabind::def("util_load_and_spawn_entities_from_script", UTIL_LoadAndSpawnEntitiesFromScript),
		luabind::def("util_bound_to_world_size", UTIL_BoundToWorldSize)
	];
END_LUA
#endif // MOD_LUA